<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DialogGraph</name>
    <message>
        <location filename="../ui/graphDialog.ui" line="14"/>
        <source>Graph</source>
        <translation>图</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="23"/>
        <source>Please wait ...</source>
        <translation>请稍候。。。</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="70"/>
        <location filename="../ui/graphDialog.ui" line="73"/>
        <source>Zoom Out</source>
        <translation>缩小</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="93"/>
        <location filename="../ui/graphDialog.ui" line="96"/>
        <source>Zoom In</source>
        <translation>放大</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="123"/>
        <source>Number of levels:</source>
        <translation>级别数:</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="153"/>
        <location filename="../ui/graphDialog.ui" line="156"/>
        <location filename="../ui/graphDialog.ui" line="159"/>
        <source>Save to DOT file</source>
        <translation>将保存到点文件</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="172"/>
        <location filename="../ui/graphDialog.ui" line="175"/>
        <location filename="../ui/graphDialog.ui" line="178"/>
        <source>Save Image</source>
        <translation>保存图像</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="191"/>
        <location filename="../ui/graphDialog.ui" line="194"/>
        <location filename="../ui/graphDialog.ui" line="197"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainWindow.ui" line="14"/>
        <source>CodeQuery</source>
        <translation>CodeQuery</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="27"/>
        <location filename="../ui/mainWindow.ui" line="30"/>
        <source>Open Database</source>
        <translation>打开的数据库</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="76"/>
        <source>Auto-complete</source>
        <translation>自动完成</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="90"/>
        <source>Exact match</source>
        <translation>精确匹配</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="104"/>
        <location filename="../ui/mainWindow.ui" line="107"/>
        <source>File path filter</source>
        <translation>文件路径筛选器</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="110"/>
        <source>Filter</source>
        <translation>筛选器</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="126"/>
        <location filename="../ui/mainWindow.ui" line="129"/>
        <source>File path filter, wildcard searches (* and ?) are supported</source>
        <translation>文件路径筛选器、 通配符搜索 （* 和?） 支持</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="152"/>
        <location filename="../ui/mainWindow.ui" line="155"/>
        <source>Previous search term</source>
        <translation>以前的搜索词</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="175"/>
        <location filename="../ui/mainWindow.ui" line="178"/>
        <source>Next search term</source>
        <translation>下一个搜索词</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="204"/>
        <location filename="../ui/mainWindow.ui" line="207"/>
        <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
        <translation>如果精确匹配关掉，通配符搜索 （* 和?） 支持</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="226"/>
        <location filename="../ui/mainWindow.ui" line="229"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="249"/>
        <location filename="../ui/mainWindow.ui" line="252"/>
        <source>Paste and Search</source>
        <translation>粘贴并搜索</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="275"/>
        <location filename="../ui/mainWindow.ui" line="278"/>
        <source>Draw graph</source>
        <translation>绘制关系图</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="335"/>
        <location filename="../ui/mainWindow.ui" line="338"/>
        <source>Previous File</source>
        <translation>以前的文件</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="358"/>
        <location filename="../ui/mainWindow.ui" line="361"/>
        <source>Next File</source>
        <translation>下一个文件</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="381"/>
        <location filename="../ui/mainWindow.ui" line="384"/>
        <source>Open in Editor</source>
        <translation>在编辑器中打开</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="404"/>
        <location filename="../ui/mainWindow.ui" line="407"/>
        <source>Go to selected line</source>
        <translation>转到所选行</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="427"/>
        <location filename="../ui/mainWindow.ui" line="430"/>
        <source>Reduce font size</source>
        <translation>减小字体大小</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="450"/>
        <location filename="../ui/mainWindow.ui" line="453"/>
        <source>Increase font size</source>
        <translation>增加字体大小</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="480"/>
        <location filename="../ui/mainWindow.ui" line="483"/>
        <source>Copy, paste and search</source>
        <translation>复制、 粘贴和搜索</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="503"/>
        <location filename="../ui/mainWindow.ui" line="506"/>
        <source>Symbol search only for paste and search</source>
        <translation>仅用于粘贴和搜索符号搜索</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="509"/>
        <source>Symbol only</source>
        <translation>只有符号</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="523"/>
        <location filename="../ui/mainWindow.ui" line="526"/>
        <source>Previous search result in this file</source>
        <translation>此文件中的上一个搜索结果</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="546"/>
        <location filename="../ui/mainWindow.ui" line="549"/>
        <source>Next search result in this file</source>
        <translation>在此文件中的下一个搜索结果</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="581"/>
        <source>FilePath:0</source>
        <translation>FilePath:0</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="610"/>
        <source>Sort by line number</source>
        <translation>按行号排序</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="615"/>
        <source>Sort by name</source>
        <translation>按名称排序</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="665"/>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="672"/>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="680"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="692"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="700"/>
        <source>Open</source>
        <translation>开放</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="705"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="710"/>
        <source>External Editor</source>
        <translation>外部编辑器</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="715"/>
        <source>Open CQ Database</source>
        <translation>打开 CQ 数据库</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="720"/>
        <source>Language</source>
        <translation>语言</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="725"/>
        <source>About Qt</source>
        <translation>关于 Qt</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="733"/>
        <source>File Viewer Settings</source>
        <translation>文件查看器设置</translation>
    </message>
</context>
<context>
    <name>aboutDialog</name>
    <message>
        <location filename="../ui/aboutDialog.ui" line="20"/>
        <source>About CodeQuery</source>
        <translation>关于 CodeQuery</translation>
    </message>
    <message>
        <location filename="../ui/aboutDialog.ui" line="116"/>
        <source>OK</source>
        <translation>还行</translation>
    </message>
</context>
<context>
    <name>cqDialogGraph</name>
    <message>
        <location filename="../graphdialog.cpp" line="89"/>
        <source>Images</source>
        <translation>图像</translation>
    </message>
    <message>
        <location filename="../graphdialog.cpp" line="92"/>
        <source>Export Image</source>
        <translation>导出图像</translation>
    </message>
    <message>
        <location filename="../graphdialog.cpp" line="103"/>
        <location filename="../graphdialog.cpp" line="122"/>
        <source>File could not be saved!</source>
        <translation>无法保存文件 ！</translation>
    </message>
    <message>
        <location filename="../graphdialog.cpp" line="111"/>
        <source>Export DOT file</source>
        <translation>出口点文件</translation>
    </message>
</context>
<context>
    <name>fileViewSettingsDialog</name>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="14"/>
        <source>File Viewer Settings</source>
        <translation>文件查看器设置</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="33"/>
        <source>Font</source>
        <translation>字体</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="46"/>
        <source>Syntax highlight theme</source>
        <translation>语法突出显示主题</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="59"/>
        <source>Tab Width (number of spaces)</source>
        <translation>标签宽度 （空格的数量）</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="119"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="132"/>
        <source>OK</source>
        <translation>还行</translation>
    </message>
</context>
<context>
    <name>fileviewer</name>
    <message>
        <location filename="../fileviewer.cpp" line="249"/>
        <source>File not found</source>
        <translation>找不到文件</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="256"/>
        <source>File could not be opened</source>
        <translation>不能打开文件</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="270"/>
        <source>The source file to be viewed is newer than the CodeQuery database file. You are recommended to manually regenerate the CodeQuery database file.</source>
        <translation>要查看源文件是比 CodeQuery 数据库文件更新。建议您手动重新生成的 CodeQuery 数据库文件。</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="533"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="534"/>
        <source>OK</source>
        <translation>还行</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="536"/>
        <source>External Editor Configuration</source>
        <translation>外部编辑器配置</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="537"/>
        <source>Please enter the path and arguments for the external editor. Replace as follows:</source>
        <translation>请输入路径和参数的外部编辑器。替换，如下所示：</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="539"/>
        <source>for file path</source>
        <translation>文件路径</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="541"/>
        <source>for line number</source>
        <translation>为行号</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="543"/>
        <source>For example:</source>
        <translation>例如：</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="568"/>
        <source>File could not be opened!</source>
        <translation>不能打开文件 ！</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="593"/>
        <source>External editor could not be started. Please check Options!</source>
        <translation>无法启动外部编辑器。请检查选项 ！</translation>
    </message>
</context>
<context>
    <name>listhandler</name>
    <message>
        <location filename="../listhandler.cpp" line="129"/>
        <source>Symbol</source>
        <translation>符号</translation>
    </message>
    <message>
        <location filename="../listhandler.cpp" line="130"/>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../listhandler.cpp" line="133"/>
        <source>Line</source>
        <translation>行</translation>
    </message>
    <message>
        <location filename="../listhandler.cpp" line="133"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
</context>
<context>
    <name>mainwindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="168"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>OK</source>
        <translation>还行</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Language</source>
        <translation>语言</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="172"/>
        <source>Select language:</source>
        <translation>选择语言：</translation>
    </message>
</context>
<context>
    <name>searchhandler</name>
    <message>
        <location filename="../searchhandler.cpp" line="334"/>
        <source>Symbol</source>
        <translation>符号</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="337"/>
        <source>Function or macro definition (Graph available)</source>
        <translation>函数或宏的定义 （Graph 中可用)</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="349"/>
        <source>Class or struct (Graph available)</source>
        <translation>类或结构 （Graph 中可用）</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="343"/>
        <source>Functions calling this function</source>
        <translation>调用此函数的函数</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="346"/>
        <source>Functions called by this function</source>
        <translation>此函数调用的函数</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="340"/>
        <source>Calls of this function or macro</source>
        <translation>此函数或宏的调用</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="352"/>
        <source>Class which owns this member or method</source>
        <translation>拥有此成员或方法的类</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="355"/>
        <source>Members or methods of this class</source>
        <translation>此类方法或成员</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="358"/>
        <source>Parent of this class</source>
        <translation>此类的父</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="361"/>
        <source>Children of this class</source>
        <translation>儿童的此类</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="364"/>
        <source>Files including this file</source>
        <translation>此文件包括文件</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="367"/>
        <source>Full path for file</source>
        <translation>文件的完整路径</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="370"/>
        <source>Functions or macros inside this file</source>
        <translation>函数或此文件中的宏</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="381"/>
        <source>CodeQuery DB Files</source>
        <translation>CodeQuery DB 文件</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="384"/>
        <source>Open CQ database file</source>
        <translation>打开 CQ 数据库文件</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="453"/>
        <source>Function Call Graph</source>
        <translation>函数的调用关系图</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="457"/>
        <source>Class Inheritance Graph</source>
        <translation>类继承关系图</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="473"/>
        <location filename="../searchhandler.cpp" line="476"/>
        <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
        <translation>如果精确匹配关掉，通配符搜索 （* 和?） 支持</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="548"/>
        <source>results found</source>
        <translation>找到的结果</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="567"/>
        <source>in progress</source>
        <translation>在进行中</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="568"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="665"/>
        <source>You have to first select an item from the list before pushing the Graph button.</source>
        <translation>您必须先推图形按钮之前从列表中选择一个项。</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="794"/>
        <source>File open error</source>
        <translation>文件打开错误</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="795"/>
        <source>Wrong file format</source>
        <translation>错误的文件格式</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="796"/>
        <source>Incorrect CQ database version</source>
        <translation>CQ 数据库版本不正确</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="797"/>
        <source>OK</source>
        <translation>还行</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="799"/>
        <source>Unknown Error</source>
        <translation>未知的错误</translation>
    </message>
</context>
</TS>
